#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_document_clear(doc: *mut TxDocument)Expand description
Clears the document, removing all nodes and resetting to an empty state.
Safety
doc must be a valid, non-null pointer to a TxDocument.
#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_document_clear(doc: *mut TxDocument)Clears the document, removing all nodes and resetting to an empty state.
doc must be a valid, non-null pointer to a TxDocument.