tx_document_free

Function tx_document_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_document_free(doc: *mut TxDocument)
Frees a document previously created with tx_document_new.

Safety

doc must be a valid pointer returned by tx_document_new, or null. After this call, the pointer must not be used again.