tx_document_to_string

Function tx_document_to_string 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_document_to_string( doc: *mut TxDocument, ) -> *const c_char
Returns the pretty-printed XML string for the document.

The returned pointer is valid until the next mutating operation on the document or until the document is freed.

Safety

doc must be a valid, non-null pointer to a TxDocument.