tx_document_to_string_compact

Function tx_document_to_string_compact 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_document_to_string_compact( doc: *mut TxDocument, ) -> *const c_char
Returns the compact XML string for the document.

The returned pointer is valid until the next mutating operation on the document or until the document is freed.

Safety

doc must be a valid, non-null pointer to a TxDocument.