tx_element_attribute

Function tx_element_attribute 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_element_attribute( doc: *mut TxDocument, el: TxNodeId, name: *const c_char, ) -> *const c_char
Returns the value of the named attribute on an element.

Returns null if the element or attribute does not exist.

Safety

  • doc must be a valid, non-null pointer to a TxDocument.
  • name must be a valid, non-null pointer to a null-terminated UTF-8 string.