tx_element_name

Function tx_element_name 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_element_name( doc: *mut TxDocument, element: TxNodeId, ) -> *const c_char
Returns the tag name of an element node.

The returned pointer is valid until the next mutating operation on the document or until the document is freed.

Safety

  • doc must be a valid, non-null pointer to a TxDocument.
  • element must identify an element node.