tx_first_child_element

Function tx_first_child_element 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_first_child_element( doc: *const TxDocument, node: TxNodeId, name: *const c_char, ) -> TxNodeId
Returns the first child element, optionally filtered by tag name.

If name is null, returns the first child element regardless of its name.

Safety

  • doc must be a valid, non-null pointer to a TxDocument.
  • name, if non-null, must be a valid null-terminated UTF-8 string.