tx_next_sibling_element

Function tx_next_sibling_element 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_next_sibling_element( doc: *const TxDocument, node: TxNodeId, name: *const c_char, ) -> TxNodeId
Returns the next sibling element, optionally filtered by tag name.

If name is null, returns the next sibling element regardless of its name.

Safety

  • doc must be a valid, non-null pointer to a TxDocument.
  • name, if non-null, must be a valid null-terminated UTF-8 string.