tx_printer_free

Function tx_printer_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_printer_free(printer: *mut TxPrinter)
Frees a printer previously created with tx_printer_new or tx_printer_new_compact.

Safety

printer must be a valid pointer returned by a printer constructor, or null. After this call, the pointer must not be used again.