tx_printer_result

Function tx_printer_result 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tx_printer_result( printer: *mut TxPrinter, ) -> *const c_char
Returns the accumulated printer output as a C string.

The returned pointer is valid until the printer is modified or freed.

Safety

printer must be a valid, non-null pointer to a TxPrinter.