#[repr(C)]pub enum TxError {
Show 18 variants
TxSuccess = 0,
TxErrorEmptyDocument = 1,
TxErrorParsingElement = 2,
TxErrorParsingAttribute = 3,
TxErrorParsingText = 4,
TxErrorParsingCdata = 5,
TxErrorParsingComment = 6,
TxErrorParsingDeclaration = 7,
TxErrorParsingUnknown = 8,
TxErrorMismatchedElement = 9,
TxErrorFileNotFound = 10,
TxErrorFileRead = 11,
TxErrorElementDepthExceeded = 12,
TxErrorNoAttribute = 13,
TxErrorWrongAttributeType = 14,
TxErrorCanNotConvertText = 15,
TxErrorNoTextNode = 16,
TxErrorInvalidNodeId = 17,
}Expand description
C-compatible error code enum matching TinyXML2 error values.
Variants
TxSuccess = 0
Operation completed successfully.
TxErrorEmptyDocument = 1
The document was empty or contained no XML content.
TxErrorParsingElement = 2
Error while parsing an element.
TxErrorParsingAttribute = 3
Error while parsing an attribute.
TxErrorParsingText = 4
Error while parsing text content.
TxErrorParsingCdata = 5
Error while parsing a CDATA section.
TxErrorParsingComment = 6
Error while parsing a comment.
TxErrorParsingDeclaration = 7
Error while parsing a declaration.
TxErrorParsingUnknown = 8
Error while parsing an unknown construct.
TxErrorMismatchedElement = 9
An element’s closing tag did not match its opening tag.
TxErrorFileNotFound = 10
The specified file was not found.
TxErrorFileRead = 11
An error occurred while reading/writing a file.
TxErrorElementDepthExceeded = 12
The maximum element nesting depth was exceeded.
TxErrorNoAttribute = 13
The requested attribute does not exist.
TxErrorWrongAttributeType = 14
The attribute value could not be converted to the requested type.
TxErrorCanNotConvertText = 15
Text content could not be converted to the requested type.
TxErrorNoTextNode = 16
No text node was found as a child of the element.
TxErrorInvalidNodeId = 17
The provided node ID is invalid or refers to a freed node.
Implementations
Sourceimpl TxError
impl TxError
Sourcepub fn from_xml_error(err: &XmlError) -> Self
pub fn from_xml_error(err: &XmlError) -> Self
Converts a Rust XmlError into a C-compatible TxError code.
Sourcepub fn from_result<T>(result: &Result<T>) -> Self
pub fn from_result<T>(result: &Result<T>) -> Self
Converts a Result<T> into a TxError, mapping Ok to TxSuccess.