#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_document_error_name(
doc: *mut TxDocument,
) -> *const c_charExpand description
Returns the error name string, or null if no error.
The returned pointer is valid until the next mutating operation on the document or until the document is freed.
Safety
doc must be a valid, non-null pointer to a TxDocument.