tx_document_new

Function tx_document_new 

#[unsafe(no_mangle)]
pub extern "C" fn tx_document_new() -> *mut TxDocument
Creates a new, empty XML document.

The returned pointer must eventually be freed with tx_document_free.

Safety

The caller must free the returned pointer with tx_document_free when done. Returns null on allocation failure.