#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_element_attribute(
doc: *mut TxDocument,
el: TxNodeId,
name: *const c_char,
) -> *const c_charExpand description
Returns the value of the named attribute on an element.
Returns null if the element or attribute does not exist.
Safety
docmust be a valid, non-null pointer to aTxDocument.namemust be a valid, non-null pointer to a null-terminated UTF-8 string.