#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_element_name(
doc: *mut TxDocument,
element: TxNodeId,
) -> *const c_charExpand description
Returns the tag name of an element node.
The returned pointer is valid until the next mutating operation on the document or until the document is freed.
Safety
docmust be a valid, non-null pointer to aTxDocument.elementmust identify an element node.