#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_first_child_element(
doc: *const TxDocument,
node: TxNodeId,
name: *const c_char,
) -> TxNodeIdExpand description
Returns the first child element, optionally filtered by tag name.
If name is null, returns the first child element regardless of its name.
Safety
docmust be a valid, non-null pointer to aTxDocument.name, if non-null, must be a valid null-terminated UTF-8 string.