#[unsafe(no_mangle)]pub unsafe extern "C" fn tx_next_sibling_element(
doc: *const TxDocument,
node: TxNodeId,
name: *const c_char,
) -> TxNodeIdExpand description
Returns the next sibling element, optionally filtered by tag name.
If name is null, returns the next sibling element regardless of its name.
Safety
docmust be a valid, non-null pointer to aTxDocument.name, if non-null, must be a valid null-terminated UTF-8 string.